#define VALUE_NOT_FOUND 0xFFFFFFF

static const int64_t AV_CODEC_ID_VIDEO_TAB[][2] = {
  {(1963793951), AV_CODEC_ID_MPEG1VIDEO},
  {(1103353565), AV_CODEC_ID_MPEG2VIDEO},
  {(1601894731), AV_CODEC_ID_H261},
  {(1601894735), AV_CODEC_ID_H263},
  {(1830446983), AV_CODEC_ID_RV10},
  {(1830447429), AV_CODEC_ID_RV20},
  {(947993323), AV_CODEC_ID_MJPEG},
  {(949113499), AV_CODEC_ID_MJPEGB},
  {(297013737), AV_CODEC_ID_LJPEG},
  {(1852031297), AV_CODEC_ID_SP5X},
  {(-1397391713), AV_CODEC_ID_JPEGLS},
  {(1079974879), AV_CODEC_ID_MPEG4},
  {(-1099095193), AV_CODEC_ID_RAWVIDEO},
  {(422477833), AV_CODEC_ID_MSMPEG4V1},
  {(422477835), AV_CODEC_ID_MSMPEG4V2},
  {(422477837), AV_CODEC_ID_MSMPEG4V3},
  {(1940478307), AV_CODEC_ID_WMV1},
  {(1940478309), AV_CODEC_ID_WMV2},
  {(740240339), AV_CODEC_ID_H263P},
  {(740240325), AV_CODEC_ID_H263I},
  {(1563333571), AV_CODEC_ID_FLV1},
  {(1852654663), AV_CODEC_ID_SVQ1},
  {(1852654667), AV_CODEC_ID_SVQ3},
  {(-510105837), AV_CODEC_ID_DVVIDEO},
  {(-253524197), AV_CODEC_ID_HUFFYUV},
  {(1498088815), AV_CODEC_ID_CYUV},
  {(1601894737), AV_CODEC_ID_H264},
  {(-1861287339), AV_CODEC_ID_INDEO3},
  {(8603443), AV_CODEC_ID_VP3},
  {(1971035227), AV_CODEC_ID_THEORA},
  {(1453134107), AV_CODEC_ID_ASV1},
  {(1453134109), AV_CODEC_ID_ASV2},
  {(1562736823), AV_CODEC_ID_FFV1},
  {(2112243285), AV_CODEC_ID_4XM},
  {(1917302809), AV_CODEC_ID_VCR1},
  {(1496790947), AV_CODEC_ID_CLJR},
  {(1717784363), AV_CODEC_ID_MDEC},
  {(8205289), AV_CODEC_ID_ROQ},
  {(1815049561), AV_CODEC_ID_INTERPLAY_VIDEO},
  {(1383142107), AV_CODEC_ID_XAN_WC3},
  {(1383142109), AV_CODEC_ID_XAN_WC4},
  {(1829882891), AV_CODEC_ID_RPZA},
  {(-310031877), AV_CODEC_ID_CINEPAK},
  {(2123143175), AV_CODEC_ID_WS_VQA},
  {(1147807563), AV_CODEC_ID_MSRLE},
  {(-1882388807), AV_CODEC_ID_MSVIDEO1},
  {(-1790290981), AV_CODEC_ID_IDCIN},
  {(-1329620199), AV_CODEC_ID_8BPS},
  {(8303827), AV_CODEC_ID_SMC},
  {(1563327873), AV_CODEC_ID_FLIC},
  {(330366747), AV_CODEC_ID_TRUEMOTION1},
  {(1015291997), AV_CODEC_ID_VMDVIDEO},
  {(1719285609), AV_CODEC_ID_MSZH},
  {(2006910551), AV_CODEC_ID_ZLIB},
  {(-521062255), AV_CODEC_ID_QTRLE},
  {(1874529279), AV_CODEC_ID_TSCC},
  {(1896019801), AV_CODEC_ID_ULTI},
  {(-875933269), AV_CODEC_ID_QDRAW},
  {(1917902351), AV_CODEC_ID_VIXL},
  {(1807694403), AV_CODEC_ID_QPEG},
  {(8005907), AV_CODEC_ID_PNG},
  {(8006811), AV_CODEC_ID_PPM},
  {(8000567), AV_CODEC_ID_PBM},
  {(8002797), AV_CODEC_ID_PGM},
  {(645278921), AV_CODEC_ID_PGMYUV},
  {(8000121), AV_CODEC_ID_PAM},
  {(-1152772281), AV_CODEC_ID_FFVHUFF},
  {(1830447875), AV_CODEC_ID_RV30},
  {(1830448321), AV_CODEC_ID_RV40},
  {(8597641), AV_CODEC_ID_VC1},
  {(1940478311), AV_CODEC_ID_WMV3},
  {(1696698399), AV_CODEC_ID_LOCO},
  {(1940577765), AV_CODEC_ID_WNV1},
  {(1451342625), AV_CODEC_ID_AASC},
  {(-1861287341), AV_CODEC_ID_INDEO2},
  {(862049649), AV_CODEC_ID_FRAPS},
  {(330366749), AV_CODEC_ID_TRUEMOTION2},
  {(6613067), AV_CODEC_ID_BMP},
  {(1497484003), AV_CODEC_ID_CSCD},
  {(-1683078665), AV_CODEC_ID_MMVIDEO},
  {(2007006927), AV_CODEC_ID_ZMBV},
  {(6517629), AV_CODEC_ID_AVS},
  {(-771171687), AV_CODEC_ID_SMACKVIDEO},
  {(7810143), AV_CODEC_ID_NUV},
  {(1674328799), AV_CODEC_ID_KMVC},
  {(1731533927), AV_CODEC_ID_FLASHSV},
  {(1495702263), AV_CODEC_ID_CAVS},
  {(385271821), AV_CODEC_ID_JPEG2000},
  {(1918295705), AV_CODEC_ID_VMNC},
  {(8603447), AV_CODEC_ID_VP5},
  {(8603449), AV_CODEC_ID_VP6},
  {(1918569109), AV_CODEC_ID_VP6F},
  {(1010470719), AV_CODEC_ID_TARGA},
  {(20187291), AV_CODEC_ID_DSICINVIDEO},
  {(1412959939), AV_CODEC_ID_TIERTEXSEQVIDEO},
  {(1873536043), AV_CODEC_ID_TIFF},
  {(7108553), AV_CODEC_ID_GIF},
  {(6816859), AV_CODEC_ID_DXA},
  {(-526342123), AV_CODEC_ID_DNXHD},
  {(8401081), AV_CODEC_ID_THP},
  {(8301163), AV_CODEC_ID_SGI},
  {(6689211), AV_CODEC_ID_C93},
  {(8664033), AV_CODEC_ID_BETHSOFTVID},
  {(8008617), AV_CODEC_ID_PTX},
  {(8408193), AV_CODEC_ID_TXD},
  {(1918569099), AV_CODEC_ID_VP6A},
  {(6513621), AV_CODEC_ID_AMV},
  {(38553), AV_CODEC_ID_VB},
  {(8001035), AV_CODEC_ID_PCX},
  {(-908217607), AV_CODEC_ID_SUNRAST},
  {(-1861287337), AV_CODEC_ID_INDEO4},
  {(-1861287335), AV_CODEC_ID_INDEO5},
  {(925517591), AV_CODEC_ID_MIMIC},
  {(8203825), AV_CODEC_ID_RL2},
  {(1406974565), AV_CODEC_ID_ESCAPE124},
  {(-637837665), AV_CODEC_ID_DIRAC},
  {(6609931), AV_CODEC_ID_BFI},
  {(6712537), AV_CODEC_ID_CMV},
  {(185768967), AV_CODEC_ID_MOTIONPIXELS},
  {(8400647), AV_CODEC_ID_TGV},
  {(8400637), AV_CODEC_ID_TGQ},
  {(8405081), AV_CODEC_ID_TQI},
  {(1453331335), AV_CODEC_ID_AURA},
  {(1970340383), AV_CODEC_ID_AURA2},
  {(1263521339), AV_CODEC_ID_V210X},
  {(8403323), AV_CODEC_ID_TMV},
  {(1912400375), AV_CODEC_ID_V210},
  {(6813337), AV_CODEC_ID_DPX},
  {(7701729), AV_CODEC_ID_MAD},
  {(1563930901), AV_CODEC_ID_FRWU},
  {(-414991041), AV_CODEC_ID_FLASHSV2},
  {(-1738229479), AV_CODEC_ID_CDGRAPHICS},
  {(1823683839), AV_CODEC_ID_R210},
  {(6514049), AV_CODEC_ID_ANM},
  {(1789210671), AV_CODEC_ID_BINKVIDEO},
  {(1145236425), AV_CODEC_ID_IFF_ILBM},
  {(1673731951), AV_CODEC_ID_KGV1},
  {(8901493), AV_CODEC_ID_YOP},
  {(8603453), AV_CODEC_ID_VP8},
  {(1724946779), AV_CODEC_ID_PICTOR},
  {(1452635591), AV_CODEC_ID_ANSI},
  {(1024547187), AV_CODEC_ID_A64_MULTI},
  {(840755897), AV_CODEC_ID_A64_MULTI5},
  {(1823584053), AV_CODEC_ID_R10K},
  {(1258501199), AV_CODEC_ID_MXPEG},
  {(567109813), AV_CODEC_ID_LAGARITH},
  {(-740225305), AV_CODEC_ID_PRORES},
  {(33241), AV_CODEC_ID_JV},
  {(6808831), AV_CODEC_ID_DFA},
  {(-1374874735), AV_CODEC_ID_WMV3IMAGE},
  {(1095377199), AV_CODEC_ID_VC1IMAGE},
  {(-838550727), AV_CODEC_ID_UTVIDEO},
  {(889160783), AV_CODEC_ID_BMV_VIDEO},
  {(1917200779), AV_CODEC_ID_VBLE},
  {(716638061), AV_CODEC_ID_DXTORY},
  {(1912599291), AV_CODEC_ID_V410},
  {(8805579), AV_CODEC_ID_XWD},
  {(1496001515), AV_CODEC_ID_CDXL},
  {(8796231), AV_CODEC_ID_XBM},
  {(-728732515), AV_CODEC_ID_ZEROCODEC},
  {(1719282377), AV_CODEC_ID_MSS1},
  {(1719274349), AV_CODEC_ID_MSA1},
  {(1408201383), AV_CODEC_ID_TSCC2},
  {(1719381837), AV_CODEC_ID_MTS2},
  {(1496791809), AV_CODEC_ID_CLLC},
  {(1719282379), AV_CODEC_ID_MSS2},
  {(8603455), AV_CODEC_ID_VP9},
  {(6511799), AV_CODEC_ID_AIC},
  {(1406975003), AV_CODEC_ID_ESCAPE130},
  {(7084037), AV_CODEC_ID_G2M},
  {(1939673849), AV_CODEC_ID_WEBP},
  {(1892535955), AV_CODEC_ID_HNM4_VIDEO},
  {(1606995733), AV_CODEC_ID_HEVC},
  {(7009089), AV_CODEC_ID_FIC},
  {(-76960351), AV_CODEC_ID_ALIAS_PIX},
  {(1431446769), AV_CODEC_ID_BRENDER_PIX},
  {(-1208126109), AV_CODEC_ID_PAF_VIDEO},
  {(6916351), AV_CODEC_ID_EXR},
  {(8603451), AV_CODEC_ID_VP7},
  {(1850564827), AV_CODEC_ID_SANM},
  {(-2025459027), AV_CODEC_ID_SGIRLE},
  {(1719573615), AV_CODEC_ID_MVC1},
  {(1719573617), AV_CODEC_ID_MVC2},
  {(7211615), AV_CODEC_ID_HQX},
  {(1873044545), AV_CODEC_ID_TDSC},
  {(841495493), AV_CODEC_ID_HQ_HQA},
  {(7204463), AV_CODEC_ID_HAP},
  {(6807975), AV_CODEC_ID_DDS},
  {(6816901), AV_CODEC_ID_DXV},
  {(1052327985), AV_CODEC_ID_SCREENPRESSO},
  {(1830171011), AV_CODEC_ID_RSCC},
  {(1453431145), AV_CODEC_ID_AVS2},
  {(1979136821), AV_CODEC_ID_Y41P},
  {(1453430823), AV_CODEC_ID_AVRP},
  {(-1511954359), AV_CODEC_ID_012V},
  {(1453432147), AV_CODEC_ID_AVUI},
  {(1453730547), AV_CODEC_ID_AYUV},
  {(178487613), AV_CODEC_ID_TARGA_Y216},
  {(1912499403), AV_CODEC_ID_V308},
  {(1912598861), AV_CODEC_ID_V408},
  {(1985632245), AV_CODEC_ID_YUV4},
  {(1453430819), AV_CODEC_ID_AVRN},
  {(1497188299), AV_CODEC_ID_CPIA},
  {(-571375125), AV_CODEC_ID_XFACE},
  {(1851858247), AV_CODEC_ID_SNOW},
  {(-1877707191), AV_CODEC_ID_SMVJPEG},
  {(1452832273), AV_CODEC_ID_APNG},
  {(-816956621), AV_CODEC_ID_DAALA},
  {(1496193279), AV_CODEC_ID_CFHD},
  {(558155169), AV_CODEC_ID_TRUEMOTION2RT},
  {(1712688267), AV_CODEC_ID_M101},
  {(-1226868645), AV_CODEC_ID_MAGICYUV},
  {(-1652344387), AV_CODEC_ID_SHEERVIDEO},
  {(8900129), AV_CODEC_ID_YLC},
  {(8008131), AV_CODEC_ID_PSD},
  {(-2105058823), AV_CODEC_ID_PIXLET},
  {(1542100065), AV_CODEC_ID_SPEEDHQ},
  {(1563433129), AV_CODEC_ID_FMVC},
  {(1850764645), AV_CODEC_ID_SCPR},
  {(-552349731), AV_CODEC_ID_CLEARVIDEO},
  {(8802475), AV_CODEC_ID_XPM},
  {(6517497), AV_CODEC_ID_AV1},
  {(645926859), AV_CODEC_ID_BITPACKED},
  {(1719275341), AV_CODEC_ID_MSCC},
  {(1852252471), AV_CODEC_ID_SRGC},
  {(8307849), AV_CODEC_ID_SVG},
  {(7106355), AV_CODEC_ID_GDV},
  {(1563034437), AV_CODEC_ID_FITS},
  {(1629966423), AV_CODEC_ID_IMM4},
  {(-1789221097), AV_CODEC_ID_PROSUMER},
  {(1719680309), AV_CODEC_ID_MWSC},
  {(1939479851), AV_CODEC_ID_WCMV},
  {(1828387903), AV_CODEC_ID_RASC},
  {(1608980913), AV_CODEC_ID_HYMT},
  {(1453025829), AV_CODEC_ID_ARBC},
  {(6510927), AV_CODEC_ID_AGM},
  {(1697096237), AV_CODEC_ID_LSCR},
  {(8603445), AV_CODEC_ID_VP4},
};

#define AV_CODEC_ID_VIDEO_TAB_LEN 238
enum AVCodecID VideoCodecID_val(value v){
int i;
for(i=0;i<AV_CODEC_ID_VIDEO_TAB_LEN;i++){
if(v==AV_CODEC_ID_VIDEO_TAB[i][0])return AV_CODEC_ID_VIDEO_TAB[i][1];
}
return VALUE_NOT_FOUND;
}
value Val_VideoCodecID(enum AVCodecID t){
int i;
for(i=0;i<AV_CODEC_ID_VIDEO_TAB_LEN; i++){
if(t==AV_CODEC_ID_VIDEO_TAB[i][1])return AV_CODEC_ID_VIDEO_TAB[i][0];
}
return VALUE_NOT_FOUND;
}
static const int64_t AV_CODEC_ID_AUDIO_TAB[][2] = {
  {(608082073), AV_CODEC_ID_PCM_S16LE},
  {(608077613), AV_CODEC_ID_PCM_S16BE},
  {(1910041245), AV_CODEC_ID_PCM_U16LE},
  {(1910036785), AV_CODEC_ID_PCM_U16BE},
  {(-1961226347), AV_CODEC_ID_PCM_S8},
  {(-1961225455), AV_CODEC_ID_PCM_U8},
  {(-1784248469), AV_CODEC_ID_PCM_MULAW},
  {(-101711219), AV_CODEC_ID_PCM_ALAW},
  {(652042509), AV_CODEC_ID_PCM_S32LE},
  {(652038049), AV_CODEC_ID_PCM_S32BE},
  {(1954001681), AV_CODEC_ID_PCM_U32LE},
  {(1953997221), AV_CODEC_ID_PCM_U32BE},
  {(630062291), AV_CODEC_ID_PCM_S24LE},
  {(630057831), AV_CODEC_ID_PCM_S24BE},
  {(1932021463), AV_CODEC_ID_PCM_U24LE},
  {(1932017003), AV_CODEC_ID_PCM_U24BE},
  {(403416569), AV_CODEC_ID_PCM_S24DAUD},
  {(453073063), AV_CODEC_ID_PCM_ZORK},
  {(898067419), AV_CODEC_ID_PCM_S16LE_PLANAR},
  {(731724571), AV_CODEC_ID_PCM_DVD},
  {(779238023), AV_CODEC_ID_PCM_F32BE},
  {(779242483), AV_CODEC_ID_PCM_F32LE},
  {(845974341), AV_CODEC_ID_PCM_F64BE},
  {(845978801), AV_CODEC_ID_PCM_F64LE},
  {(1056903817), AV_CODEC_ID_PCM_BLURAY},
  {(732521131), AV_CODEC_ID_PCM_LXF},
  {(-667336873), AV_CODEC_ID_S302M},
  {(-1102115745), AV_CODEC_ID_PCM_S8_PLANAR},
  {(907698913), AV_CODEC_ID_PCM_S24LE_PLANAR},
  {(917330407), AV_CODEC_ID_PCM_S32LE_PLANAR},
  {(-1163184185), AV_CODEC_ID_PCM_S16BE_PLANAR},
  {(718778827), AV_CODEC_ID_PCM_S64LE},
  {(718774367), AV_CODEC_ID_PCM_S64BE},
  {(735282047), AV_CODEC_ID_PCM_F16LE},
  {(757262265), AV_CODEC_ID_PCM_F24LE},
  {(363753519), AV_CODEC_ID_PCM_VIDC},
  {(131429211), AV_CODEC_ID_ADPCM_IMA_QT},
  {(-755468731), AV_CODEC_ID_ADPCM_IMA_WAV},
  {(-757354107), AV_CODEC_ID_ADPCM_IMA_DK3},
  {(-757354105), AV_CODEC_ID_ADPCM_IMA_DK4},
  {(131431885), AV_CODEC_ID_ADPCM_IMA_WS},
  {(330850329), AV_CODEC_ID_ADPCM_IMA_SMJPEG},
  {(-1437345827), AV_CODEC_ID_ADPCM_MS},
  {(1588760899), AV_CODEC_ID_ADPCM_4XM},
  {(-1437340957), AV_CODEC_ID_ADPCM_XA},
  {(1593227611), AV_CODEC_ID_ADPCM_ADX},
  {(-1437349431), AV_CODEC_ID_ADPCM_EA},
  {(-1063960455), AV_CODEC_ID_ADPCM_G726},
  {(-1437350285), AV_CODEC_ID_ADPCM_CT},
  {(1595026293), AV_CODEC_ID_ADPCM_SWF},
  {(293808955), AV_CODEC_ID_ADPCM_YAMAHA},
  {(-1511839785), AV_CODEC_ID_ADPCM_SBPRO_4},
  {(-1511839787), AV_CODEC_ID_ADPCM_SBPRO_3},
  {(-1511839789), AV_CODEC_ID_ADPCM_SBPRO_2},
  {(1595119081), AV_CODEC_ID_ADPCM_THP},
  {(-757651455), AV_CODEC_ID_ADPCM_IMA_AMV},
  {(-1405913483), AV_CODEC_ID_ADPCM_EA_R1},
  {(-1405913479), AV_CODEC_ID_ADPCM_EA_R3},
  {(-1405913481), AV_CODEC_ID_ADPCM_EA_R2},
  {(1641581021), AV_CODEC_ID_ADPCM_IMA_EA_SEAD},
  {(1330676235), AV_CODEC_ID_ADPCM_IMA_EA_EACS},
  {(14524063), AV_CODEC_ID_ADPCM_EA_XAS},
  {(-446540693), AV_CODEC_ID_ADPCM_EA_MAXIS_XA},
  {(-756853121), AV_CODEC_ID_ADPCM_IMA_ISS},
  {(-1063960463), AV_CODEC_ID_ADPCM_G722},
  {(-757650155), AV_CODEC_ID_ADPCM_IMA_APC},
  {(-726274145), AV_CODEC_ID_ADPCM_VIMA},
  {(1593228461), AV_CODEC_ID_ADPCM_AFC},
  {(-756259961), AV_CODEC_ID_ADPCM_IMA_OKI},
  {(1593533095), AV_CODEC_ID_ADPCM_DTK},
  {(-755966057), AV_CODEC_ID_ADPCM_IMA_RAD},
  {(12651371), AV_CODEC_ID_ADPCM_G726LE},
  {(629273673), AV_CODEC_ID_ADPCM_THP_LE},
  {(1594726171), AV_CODEC_ID_ADPCM_PSX},
  {(-1192040419), AV_CODEC_ID_ADPCM_AICA},
  {(-1387207025), AV_CODEC_ID_ADPCM_IMA_DAT4},
  {(-924797655), AV_CODEC_ID_ADPCM_MTAF},
  {(1593228927), AV_CODEC_ID_ADPCM_AGM},
  {(386199643), AV_CODEC_ID_AMR_NB},
  {(386203657), AV_CODEC_ID_AMR_WB},
  {(-1004210045), AV_CODEC_ID_RA_144},
  {(-1004108795), AV_CODEC_ID_RA_288},
  {(-74109629), AV_CODEC_ID_ROQ_DPCM},
  {(-2046744501), AV_CODEC_ID_INTERPLAY_DPCM},
  {(-1217044639), AV_CODEC_ID_XAN_DPCM},
  {(1852339659), AV_CODEC_ID_SOL_DPCM},
  {(1522676501), AV_CODEC_ID_SDX2_DPCM},
  {(-615844561), AV_CODEC_ID_GREMLIN_DPCM},
  {(7708319), AV_CODEC_ID_MP2},
  {(7708321), AV_CODEC_ID_MP3},
  {(6508231), AV_CODEC_ID_AAC},
  {(6509027), AV_CODEC_ID_AC3},
  {(6815111), AV_CODEC_ID_DTS},
  {(799076071), AV_CODEC_ID_VORBIS},
  {(-1029623863), AV_CODEC_ID_DVAUDIO},
  {(-1067092403), AV_CODEC_ID_WMAV1},
  {(-1067092401), AV_CODEC_ID_WMAV2},
  {(747088059), AV_CODEC_ID_MACE3},
  {(747088065), AV_CODEC_ID_MACE6},
  {(495773971), AV_CODEC_ID_VMDAUDIO},
  {(1563324305), AV_CODEC_ID_FLAC},
  {(-793302587), AV_CODEC_ID_MP3ADU},
  {(-791905845), AV_CODEC_ID_MP3ON4},
  {(-1954531445), AV_CODEC_ID_SHORTEN},
  {(1452428635), AV_CODEC_ID_ALAC},
  {(288321559), AV_CODEC_ID_WESTWOOD_SND1},
  {(7113027), AV_CODEC_ID_GSM},
  {(1806504369), AV_CODEC_ID_QDM2},
  {(1497091537), AV_CODEC_ID_COOK},
  {(-1646120927), AV_CODEC_ID_TRUESPEECH},
  {(8406403), AV_CODEC_ID_TTA},
  {(-1290689713), AV_CODEC_ID_SMACKAUDIO},
  {(-899400465), AV_CODEC_ID_QCELP},
  {(1275546571), AV_CODEC_ID_WAVPACK},
  {(-499330735), AV_CODEC_ID_DSICINAUDIO},
  {(7309247), AV_CODEC_ID_IMC},
  {(-934715959), AV_CODEC_ID_MUSEPACK7},
  {(7706659), AV_CODEC_ID_MLP},
  {(-981461239), AV_CODEC_ID_GSM_MS},
  {(648283365), AV_CODEC_ID_ATRAC3},
  {(6514925), AV_CODEC_ID_APE},
  {(-743522183), AV_CODEC_ID_NELLYMOSER},
  {(-934715957), AV_CODEC_ID_MUSEPACK8},
  {(690884343), AV_CODEC_ID_SPEEX},
  {(1354431695), AV_CODEC_ID_WMAVOICE},
  {(-1738972347), AV_CODEC_ID_WMAPRO},
  {(2002018895), AV_CODEC_ID_WMALOSSLESS},
  {(-1461697667), AV_CODEC_ID_ATRAC3P},
  {(1540051929), AV_CODEC_ID_EAC3},
  {(1851361393), AV_CODEC_ID_SIPR},
  {(7708317), AV_CODEC_ID_MP1},
  {(-1060553977), AV_CODEC_ID_TWINVQ},
  {(244763605), AV_CODEC_ID_TRUEHD},
  {(-771119889), AV_CODEC_ID_MP4ALS},
  {(648283361), AV_CODEC_ID_ATRAC1},
  {(-377708709), AV_CODEC_ID_BINKAUDIO_RDFT},
  {(1268069649), AV_CODEC_ID_BINKAUDIO_DCT},
  {(-1358450283), AV_CODEC_ID_AAC_LATM},
  {(1806504467), AV_CODEC_ID_QDMC},
  {(1496095637), AV_CODEC_ID_CELT},
  {(1596485127), AV_CODEC_ID_G723_1},
  {(1580211119), AV_CODEC_ID_G729},
  {(-65302155), AV_CODEC_ID_8SVX_EXP},
  {(-65209415), AV_CODEC_ID_8SVX_FIB},
  {(369642757), AV_CODEC_ID_BMV_AUDIO},
  {(1828384787), AV_CODEC_ID_RALF},
  {(7303895), AV_CODEC_ID_IAC},
  {(1629862153), AV_CODEC_ID_ILBC},
  {(1763343295), AV_CODEC_ID_OPUS},
  {(1150262159), AV_CODEC_ID_COMFORT_NOISE},
  {(8397949), AV_CODEC_ID_TAK},
  {(1229975445), AV_CODEC_ID_METASOUND},
  {(-1727644135), AV_CODEC_ID_PAF_AUDIO},
  {(456653623), AV_CODEC_ID_ON2AVC},
  {(1732937393), AV_CODEC_ID_DSS_SP},
  {(-342638087), AV_CODEC_ID_CODEC2},
  {(1380674951), AV_CODEC_ID_FFWAVESYNTH},
  {(669602073), AV_CODEC_ID_SONIC},
  {(-1972545739), AV_CODEC_ID_SONIC_LS},
  {(1542147333), AV_CODEC_ID_EVRC},
  {(8303865), AV_CODEC_ID_SMV},
  {(-1408435221), AV_CODEC_ID_DSD_LSBF},
  {(-1386256087), AV_CODEC_ID_DSD_MSBF},
  {(935589577), AV_CODEC_ID_DSD_LSBF_PLANAR},
  {(964742475), AV_CODEC_ID_DSD_MSBF_PLANAR},
  {(2112235721), AV_CODEC_ID_4GV},
  {(876475001), AV_CODEC_ID_INTERPLAY_ACM},
  {(1962648075), AV_CODEC_ID_XMA1},
  {(1962648077), AV_CODEC_ID_XMA2},
  {(6814667), AV_CODEC_ID_DST},
  {(458928059), AV_CODEC_ID_ATRAC3AL},
  {(-736770989), AV_CODEC_ID_ATRAC3PAL},
  {(-1149987011), AV_CODEC_ID_DOLBY_E},
  {(1452834983), AV_CODEC_ID_APTX},
  {(-503198383), AV_CODEC_ID_APTX_HD},
  {(8298921), AV_CODEC_ID_SBC},
  {(648283377), AV_CODEC_ID_ATRAC9},
  {(1606793715), AV_CODEC_ID_HCOM},
};

#define AV_CODEC_ID_AUDIO_TAB_LEN 178
enum AVCodecID AudioCodecID_val(value v){
int i;
for(i=0;i<AV_CODEC_ID_AUDIO_TAB_LEN;i++){
if(v==AV_CODEC_ID_AUDIO_TAB[i][0])return AV_CODEC_ID_AUDIO_TAB[i][1];
}
return VALUE_NOT_FOUND;
}
value Val_AudioCodecID(enum AVCodecID t){
int i;
for(i=0;i<AV_CODEC_ID_AUDIO_TAB_LEN; i++){
if(t==AV_CODEC_ID_AUDIO_TAB[i][1])return AV_CODEC_ID_AUDIO_TAB[i][0];
}
return VALUE_NOT_FOUND;
}
static const int64_t AV_CODEC_ID_SUBTITLE_TAB[][2] = {
  {(1752213899), AV_CODEC_ID_DVD_SUBTITLE},
  {(1732692495), AV_CODEC_ID_DVB_SUBTITLE},
  {(1873146267), AV_CODEC_ID_TEXT},
  {(1963253841), AV_CODEC_ID_XSUB},
  {(8306499), AV_CODEC_ID_SSA},
  {(-733701455), AV_CODEC_ID_MOV_TEXT},
  {(-761651413), AV_CODEC_ID_HDMV_PGS_SUBTITLE},
  {(1854843277), AV_CODEC_ID_DVB_TELETEXT},
  {(8306091), AV_CODEC_ID_SRT},
  {(-1974487971), AV_CODEC_ID_MICRODVD},
  {(-1826020039), AV_CODEC_ID_EIA_608},
  {(812135483), AV_CODEC_ID_JACOSUB},
  {(1850564373), AV_CODEC_ID_SAMI},
  {(-33704361), AV_CODEC_ID_REALTEXT},
  {(8306967), AV_CODEC_ID_STL},
  {(-2060822273), AV_CODEC_ID_SUBVIEWER1},
  {(-1280397595), AV_CODEC_ID_SUBVIEWER},
  {(-1656934669), AV_CODEC_ID_SUBRIP},
  {(1665902341), AV_CODEC_ID_WEBVTT},
  {(1718980883), AV_CODEC_ID_MPL2},
  {(1608360047), AV_CODEC_ID_VPLAYER},
  {(8004147), AV_CODEC_ID_PJS},
  {(6516291), AV_CODEC_ID_ASS},
  {(-1185551519), AV_CODEC_ID_HDMV_TEXT_SUBTITLE},
  {(1874633215), AV_CODEC_ID_TTML},
  {(691667747), AV_CODEC_ID_ARIB_CAPTION},
};

#define AV_CODEC_ID_SUBTITLE_TAB_LEN 26
enum AVCodecID SubtitleCodecID_val(value v){
int i;
for(i=0;i<AV_CODEC_ID_SUBTITLE_TAB_LEN;i++){
if(v==AV_CODEC_ID_SUBTITLE_TAB[i][0])return AV_CODEC_ID_SUBTITLE_TAB[i][1];
}
return VALUE_NOT_FOUND;
}
value Val_SubtitleCodecID(enum AVCodecID t){
int i;
for(i=0;i<AV_CODEC_ID_SUBTITLE_TAB_LEN; i++){
if(t==AV_CODEC_ID_SUBTITLE_TAB[i][1])return AV_CODEC_ID_SUBTITLE_TAB[i][0];
}
return VALUE_NOT_FOUND;
}
